@@ -3,7 +3,7 @@ package BorderStyleBase;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-11'; # DATE
 our $DIST = 'BorderStyleBase'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use strict 'subs', 'vars';
 #use warnings;
@@ -36,7 +36,7 @@ sub get_border_char {
         }
         return $c2;
     } else {
-        $c = $c x $n if $n > 1;
+        $c = $c x $n if $n != 1;
         $c = "\e(0$c\e(B" if $bs_struct->{box_chars};
     }
     $c;
@@ -57,7 +57,7 @@ BorderStyleBase - A suitable base class for most BorderStyle::* modules
 
 =head1 VERSION
 
-This document describes version 0.001 of BorderStyleBase (from Perl distribution BorderStyleBase), released on 2020-06-11.
+This document describes version 0.002 of BorderStyleBase (from Perl distribution BorderStyleBase), released on 2020-06-11.
 
 =head1 DESCRIPTION
 
